@@ -3,14 +3,13 @@ package Firewall::Config::Dao::Parser::Role;
 #------------------------------------------------------------------------------
 # 加载扩展插件
 #------------------------------------------------------------------------------
-use JSON;
-use utf8;
 use Moose::Role;
 use namespace::autoclean;
+use JSON;
 use Storable qw(dclone);
 
 #------------------------------------------------------------------------------
-# 加载解析插件
+# 加载项目模块
 #------------------------------------------------------------------------------
 use Firewall::Utils::Date;
 use Firewall::Utils::Ip;
